@@ -503,7 +503,7 @@ void Titraqform::setupMenubar(void)
     m_pMenubar->insertItem(trUtf8("&Help"), pHelppopup);
     pHelppopup->insertItem(trUtf8("&Contents"), this, SLOT(helpContents()), Key_F1);
     pHelppopup->insertSeparator();
-    pHelppopup->insertItem(trUtf8("About &AS-GUI"), this, SLOT(aboutTitraq()));
+    pHelppopup->insertItem(trUtf8("About &as-gui"), this, SLOT(aboutTitraq()));
     pHelppopup->insertItem(trUtf8("About &OSSP"), this, SLOT(aboutOSSP()));
     pHelppopup->insertItem(trUtf8("About &Qt"), this, SLOT(aboutQt()));
     pHelppopup->insertSeparator();
