@@ -65,7 +65,7 @@ Rand::Rand(void)
 }
 
 // Destructor
-Rand::~Rand()
+Rand::~Rand(void)
 {
     this->closeDevice();  // Close the random device
     this->nFd = -4; // Return this object to its fresh status
