@@ -34,6 +34,8 @@
 
 #include <qtable.h>
 
+#include "as_pref.h"
+
 
 class TiTable : public QTable
 {
@@ -43,15 +45,17 @@ private:
     int  m_nSortcol;    // To track current sort column
     int  m_bSortdir;    // To track current sort direction
     bool m_bDirt;       // To track dirty and clean states
+    Preferences *m_pTiprefs; // To read current color values
 
 public:
     // Try to match QTable's default constructor with an initializer list
-    TiTable(QWidget *pParent = 0, const char *szName = 0) : QTable(pParent, szName)
+    TiTable(Preferences *pPrefs, QWidget *pParent = 0, const char *szName = 0) : QTable(pParent, szName)
     {
         this->setSortcol(0);
         this->setSortdir(true);
         this->setDirty(false);
         this->setEdition(); // Reset edition state
+        m_pTiprefs = pPrefs;
         horizontalHeader()->installEventFilter(this);
     };
 
